==================================
 Mockstar -- mock like a rockstar
==================================

Mockstar is a small enhance on top of `Mock
<http://www.voidspace.org.uk/python/mock/mock.html>`_ library that
gives you declarative way to write your unit-tests.

Documentation: `http://mockstar.readthedocs.org
<http://mockstar.readthedocs.org>`_.
